OpenTelemetry Scenario Tester
=============================

The oteltest package contains utilities for testing OpenTelemetry Python scenarios.


References
----------
* `OpenTelemetry Project <https://opentelemetry.io/>`_
